@@ -23,12 +23,13 @@ import java.util.zip.CRC32;
 import java.util.zip.ZipEntry;
 import java.util.zip.ZipOutputStream;
 
-import org.eclipse.jdt.core.compiler.InvalidInputException;
 import org.eclipse.jdt.internal.compiler.ClassFile;
 import org.eclipse.jdt.internal.compiler.CompilationResult;
+import org.eclipse.jdt.internal.compiler.env.AccessRestriction;
 import org.eclipse.jdt.internal.compiler.env.AccessRule;
 import org.eclipse.jdt.internal.compiler.env.AccessRuleSet;
 import org.eclipse.jdt.internal.compiler.impl.CompilerOptions;
+import org.eclipse.jdt.internal.compiler.problem.ProblemSeverities;
 import org.eclipse.jdt.internal.compiler.util.Messages;
 import org.eclipse.jdt.internal.compiler.util.SuffixConstants;
 
@@ -71,11 +72,12 @@ public class GCCMain extends Main {
 	}
 
 	private void fail(Exception t) {
+		t.printStackTrace();
 		this.logger.logException(t);
 		System.exit(1);
 	}
 
-	public CompilationUnit[] getCompilationUnits() throws InvalidInputException {
+	public CompilationUnit[] getCompilationUnits() {
 		CompilationUnit[] units = super.getCompilationUnits();
 		for (int i = 0; i < units.length; ++i)
 			this.commandLineCompilationUnits.add(units[i]);
@@ -99,6 +101,16 @@ public class GCCMain extends Main {
 			}
 			zipStream = new ZipOutputStream(new BufferedOutputStream(os));
 			zipStream.setMethod(ZipOutputStream.STORED);
+			// Sun/OpenJDK require at least one entry in the zip file.
+			ZipEntry entry = new ZipEntry(".dummy");
+			byte[] contents = new byte[0];
+			CRC32 crc = new CRC32();
+			crc.update(contents);
+			entry.setSize(contents.length);
+			entry.setCrc(crc.getValue());
+			zipStream.putNextEntry(entry);
+			zipStream.write(contents);
+			zipStream.closeEntry();
 		}
 		return zipStream;
 	}
@@ -108,6 +120,16 @@ public class GCCMain extends Main {
 			OutputStream os = new FileOutputStream(zipDependencyDestination);
 			zipDependencyStream = new ZipOutputStream(new BufferedOutputStream(os));
 			zipDependencyStream.setMethod(ZipOutputStream.STORED);
+			// Sun/OpenJDK require at least one entry in the zip file.
+			ZipEntry entry = new ZipEntry(".dummy");
+			byte[] contents = new byte[0];
+			CRC32 crc = new CRC32();
+			crc.update(contents);
+			entry.setSize(contents.length);
+			entry.setCrc(crc.getValue());
+			zipDependencyStream.putNextEntry(entry);
+			zipDependencyStream.write(contents);
+			zipDependencyStream.closeEntry();
 		}
 		return zipDependencyStream;
 	}
@@ -170,20 +192,7 @@ public class GCCMain extends Main {
 	private void addPath(ArrayList result, String currentClasspathName) {
 		String customEncoding = null;
 		AccessRule[] accessRules = new AccessRule[0];
-		String templates[] = new String[AccessRuleSet.MESSAGE_TEMPLATES_LENGTH];
-		templates[0] = this.bind(
-			"template.restrictedAccess.type", //$NON-NLS-1$
-			new String[] {"{0}", currentClasspathName}); //$NON-NLS-1$ 
-		templates[1] = this.bind(
-			"template.restrictedAccess.constructor", //$NON-NLS-1$
-			new String[] {"{0}", currentClasspathName}); //$NON-NLS-1$ 
-		templates[2] = this.bind(
-			"template.restrictedAccess.method", //$NON-NLS-1$
-			new String[] {"{0}", "{1}", currentClasspathName}); //$NON-NLS-1$ //$NON-NLS-2$ 
-		templates[3] = this.bind(
-			"template.restrictedAccess.field", //$NON-NLS-1$
-			new String[] {"{0}", "{1}", currentClasspathName}); //$NON-NLS-1$ //$NON-NLS-2$ 
-		AccessRuleSet accessRuleSet = new AccessRuleSet(accessRules, templates);
+		AccessRuleSet accessRuleSet = new AccessRuleSet(accessRules, AccessRestriction.COMMAND_LINE, currentClasspathName);
 		FileSystem.Classpath currentClasspath = FileSystem
 				.getClasspath(currentClasspathName,
 						customEncoding, accessRuleSet);
@@ -199,8 +208,7 @@ public class GCCMain extends Main {
 		}
 	}
 
-	protected void handleWarningToken(String token, boolean isEnabling,
-			boolean useEnableJavadoc) throws InvalidInputException {
+	protected void handleWarningToken(String token, boolean isEnabling) {
 		// Recognize this for compatibility with older versions of gcj.
 		if ("deprecated".equals(token)) //$NON-NLS-1$
 			token = "deprecation"; //$NON-NLS-1$
@@ -228,7 +236,7 @@ public class GCCMain extends Main {
 			}
 			token = newToken.toString();
 		}
-		super.handleWarningToken(token, isEnabling, useEnableJavadoc);
+		super.handleWarningToken(token, isEnabling);
 	}
 
 	private void turnWarningsToErrors() {
@@ -283,31 +291,31 @@ public class GCCMain extends Main {
 		}
 	}
 
-	private void handleWall(boolean enable) throws InvalidInputException {
+	private void handleWall(boolean enable) {
 		// A somewhat arbitrary list.  We use the GCC names
 		// here, and the local handleWarningToken translates
 		// for us.
-		handleWarningToken("constructor-name", enable, false);
-		handleWarningToken("pkg-default-method", enable, false);
-		handleWarningToken("masked-catch-block", enable, false);
-		handleWarningToken("all-deprecation", enable, false);
-		handleWarningToken("unused-local", enable, false);
-		handleWarningToken("unused-label", enable, false);
-		handleWarningToken("static-receiver", enable, false);
-		handleWarningToken("indirect-static", enable, false);
-		handleWarningToken("no-effect-assign", enable, false);
-		handleWarningToken("char-concat", enable, false);
-		handleWarningToken("useless-type-check", enable, false);
-		handleWarningToken("final-bound", enable, false);
-		handleWarningToken("assert-identifier", enable, false);
-		handleWarningToken("enum-identifier", enable, false);
-		handleWarningToken("finally", enable, false);
-		handleWarningToken("varargs-cast", enable, false);
-		handleWarningToken("unused", enable, false);
-		handleWarningToken("forbidden", enable, false);
+		handleWarningToken("constructor-name", enable);
+		handleWarningToken("pkg-default-method", enable);
+		handleWarningToken("masked-catch-block", enable);
+		handleWarningToken("all-deprecation", enable);
+		handleWarningToken("unused-local", enable);
+		handleWarningToken("unused-label", enable);
+		handleWarningToken("static-receiver", enable);
+		handleWarningToken("indirect-static", enable);
+		handleWarningToken("no-effect-assign", enable);
+		handleWarningToken("char-concat", enable);
+		handleWarningToken("useless-type-check", enable);
+		handleWarningToken("final-bound", enable);
+		handleWarningToken("assert-identifier", enable);
+		handleWarningToken("enum-identifier", enable);
+		handleWarningToken("finally", enable);
+		handleWarningToken("varargs-cast", enable);
+		handleWarningToken("unused", enable);
+		handleWarningToken("forbidden", enable);
 	}
 
-	public void configure(String[] argv) throws InvalidInputException {
+	public void configure(String[] argv) {
 		if ((argv == null) || (argv.length == 0)) {
 			// This is a "can't happen".
 			System.exit(1);
@@ -329,7 +337,7 @@ public class GCCMain extends Main {
 				try { // ensure encoding is supported
 					new InputStreamReader(new ByteArrayInputStream(new byte[0]), encoding);
 				} catch (UnsupportedEncodingException e) {
-					throw new InvalidInputException(
+					throw new IllegalArgumentException(
 						this.bind("configure.unsupportedEncoding", encoding)); //$NON-NLS-1$
 				}
 				this.options.put(CompilerOptions.OPTION_Encoding, encoding);
@@ -340,7 +348,7 @@ public class GCCMain extends Main {
 					errorMessage.append("-d"); //$NON-NLS-1$
 					errorMessage.append(' ');
 					errorMessage.append(arg);
-					throw new InvalidInputException(
+					throw new IllegalArgumentException(
 						this.bind("configure.duplicateOutputPath", errorMessage.toString())); //$NON-NLS-1$
 				}
 				this.setDestinationPath(arg);
@@ -349,12 +357,12 @@ public class GCCMain extends Main {
 			} else if (currentArg.equals("-fzip-target")) { //$NON-NLS-1$
 				++i;
 				if (i >= argv.length)
-					throw new InvalidInputException(this.bind("gcc.zipArg")); //$NON-NLS-1$
+					throw new IllegalArgumentException(this.bind("gcc.zipArg")); //$NON-NLS-1$
 				this.zipDestination = argv[i];
 			} else if (currentArg.equals("-fzip-dependency")) { //$NON-NLS-1$
 				++i;
 				if (i >= argv.length)
-					throw new InvalidInputException(this.bind("gcc.zipDepArg")); //$NON-NLS-1$
+					throw new IllegalArgumentException(this.bind("gcc.zipDepArg")); //$NON-NLS-1$
 				this.zipDependencyDestination = argv[i];
 			} else if (currentArg.startsWith("-g")) { //$NON-NLS-1$
 				if (currentArg.equals("-g0")) { //$NON-NLS-1$
@@ -375,9 +383,9 @@ public class GCCMain extends Main {
 			} else if (currentArg.equals("-Wno-all")) { //$NON-NLS-1$
 				handleWall(false);
 			} else if (currentArg.startsWith("-Wno-")) { //$NON-NLS-1$
-				handleWarningToken(currentArg.substring(5), false, false);
+				handleWarningToken(currentArg.substring(5), false);
 			} else if (currentArg.startsWith("-W")) { //$NON-NLS-1$
-				handleWarningToken(currentArg.substring(2), true, false);
+				handleWarningToken(currentArg.substring(2), true);
 			} else if (currentArg.equals("-w")) { //$NON-NLS-1$
 				inhibitAllWarnings = true;
 			} else if (currentArg.startsWith("-O")) { //$NON-NLS-1$
@@ -397,7 +405,7 @@ public class GCCMain extends Main {
 				} else if (currentArg.equals("1.6") || currentArg.equals("6") || currentArg.equals("6.0")) { //$NON-NLS-1$//$NON-NLS-2$ //$NON-NLS-3$
 					this.options.put(CompilerOptions.OPTION_Source, CompilerOptions.VERSION_1_6);
 				} else {
-					throw new InvalidInputException(this.bind("configure.source", currentArg)); //$NON-NLS-1$
+					throw new IllegalArgumentException(this.bind("configure.source", currentArg)); //$NON-NLS-1$
 				}
 			} else if (currentArg.startsWith("-ftarget=")) { //$NON-NLS-1$
 				currentArg = getArgument(currentArg);
@@ -416,7 +424,7 @@ public class GCCMain extends Main {
 				} else if (currentArg.equals("jsr14")) { //$NON-NLS-1$
 					this.options.put(CompilerOptions.OPTION_TargetPlatform, CompilerOptions.VERSION_JSR14);
 				} else {
-					throw new InvalidInputException(this.bind("configure.targetJDK", currentArg)); //$NON-NLS-1$
+					throw new IllegalArgumentException(this.bind("configure.targetJDK", currentArg)); //$NON-NLS-1$
 				}
 			} else if (currentArg.equals("-ffilelist-file")) { //$NON-NLS-1$
 				haveFileList = true;
@@ -443,7 +451,7 @@ public class GCCMain extends Main {
 		// Classpath processing.
 		ArrayList result = new ArrayList();
 		if (classpath == null)
-			throw new InvalidInputException(this.bind("gcc.noClasspath")); //$NON-NLS-1$
+			throw new IllegalArgumentException(this.bind("gcc.noClasspath")); //$NON-NLS-1$
 		parsePath(result, classpath);
 
 		// We must always create both output files, even if one is not used.
@@ -456,7 +464,7 @@ public class GCCMain extends Main {
 		}
 
 		if (inhibitAllWarnings)
-			disableWarnings();
+			disableAll(ProblemSeverities.Warning);
 		if (treatWarningsAsErrors)
 			turnWarningsToErrors();
 
@@ -466,8 +474,8 @@ public class GCCMain extends Main {
 		this.logger.logCommandLineArguments(argv);
 		this.logger.logOptions(this.options);
 		this.logger.logClasspath(this.checkedClasspaths);
-		
-		this.repetitions = 1;
+
+		this.maxRepetition = 1;
 	}
 
 	public boolean compile(String[] argv) {
